@@ -301,8 +301,13 @@ class Helper:
     self.check_field_format("outputs", pp, node._name, node._columns)
 
   @classmethod
-  def check_loop_back(self, stream, node_name, nodes):
+  def check_loop_back(self, stream, node_name, max_iterations, nodes):
     ee = "Error in \"loop_back\" to \"%s\": \n\t "%(node_name)
+    pp = self.print_check_loop_back
+
+    if max_iterations != None and not isinstance(max_iterations, int):
+      msg = ee+"Max iterations must be an integer."+pp
+      self.print_error(msg)
 
     previous_node_name = stream._previous_node_name
     found = False
@@ -310,14 +315,14 @@ class Helper:
       if node._name == node_name:
         found = True
         if node._type == "source":
-          msg = ee+"Cannot loop back to source node \"%s\"!"%(node_name)
+          msg = ee+"Cannot loop back to source node \"%s\"!"%(node_name)+pp
           self.print_error(msg)
       if node._name == previous_node_name:
         if len(node._emits) < 2:
-          msg = ee+"The preceding operation does not emit multiple streams. Please make sure that it emits one stream for the loop back and another stream for downstream operations."
+          msg = ee+"The preceding operation does not emit multiple streams. Please make sure that it emits one stream for the loop back and another stream for downstream operations."+pp
           self.print_error(msg)
     if not found:
-      msg = ee+"The specified loop-back node \"%s\" was not found in the operations preceding it."%(node_name)
+      msg = ee+"The specified loop-back node \"%s\" was not found in the operations preceding it."%(node_name)+pp
       self.print_error(msg)
 
   print_check_source = """\n
@@ -443,3 +448,7 @@ class Helper:
       * Tuples emitted from the preceeding operation MUST contain the fields listed for the corresponding component input streams.
       * The streams specified in "outputs" must correspond to the listed output streams to the component in order.
       * The number of input and output streams specified must match the number listed for the component."""
+
+  print_check_loop_back = """\n
+"Loop_back" Syntax:
+  stream.loop_back( operation_name[str], max_iterations[int] )"""
